@@ -6,7 +6,6 @@ import os
 import platform
 import subprocess
 import locale
-import cairo
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk, Gio, Gdk, GdkPixbuf
 
@@ -84,10 +83,11 @@ class MintWelcome():
         builder.get_object("button_mintupdate").connect("clicked", self.launch, "mintupdate")
         builder.get_object("button_mintinstall").connect("clicked", self.launch, "mintinstall")
         builder.get_object("button_timeshift").connect("clicked", self.pkexec, "timeshift-gtk")
-        builder.get_object("button_mintdrivers").connect("clicked", self.pkexec, "driver-manager")
+        builder.get_object("button_mintdrivers").connect("clicked", self.launch, "driver-manager")
         builder.get_object("button_gufw").connect("clicked", self.launch, "gufw")
         builder.get_object("button_layout_legacy").connect("clicked", self.on_button_layout_clicked, LAYOUT_STYLE_LEGACY)
         builder.get_object("button_layout_new").connect("clicked", self.on_button_layout_clicked, LAYOUT_STYLE_NEW)
+        builder.get_object("go_button").connect("clicked", self.go)
 
         # Settings button depends on DE
         de_is_cinnamon = False
@@ -122,30 +122,31 @@ class MintWelcome():
             builder.get_object("box_documentation").remove(builder.get_object("box_new_features"))
 
         # Construct the stack switcher
-        list_box = builder.get_object("list_navigation")
+        self.list_box = builder.get_object("list_navigation")
 
         page = builder.get_object("page_home")
         self.stack.add_named(page, "page_home")
-        list_box.add(SidebarRow(page, _("Welcome"), "go-home-symbolic"))
+        self.list_box.add(SidebarRow(page, _("Welcome"), "go-home-symbolic"))
         self.stack.set_visible_child(page)
 
         page = builder.get_object("page_first_steps")
         self.stack.add_named(page, "page_first_steps")
-        list_box.add(SidebarRow(page, _("First Steps"), "dialog-information-symbolic"))
+        self.first_steps_row = SidebarRow(page, _("First Steps"), "dialog-information-symbolic")
+        self.list_box.add(self.first_steps_row)
 
         page = builder.get_object("page_documentation")
         self.stack.add_named(page, "page_documentation")
-        list_box.add(SidebarRow(page, _("Documentation"), "accessories-dictionary-symbolic"))
+        self.list_box.add(SidebarRow(page, _("Documentation"), "accessories-dictionary-symbolic"))
 
         page = builder.get_object("page_help")
         self.stack.add_named(page, "page_help")
-        list_box.add(SidebarRow(page, _("Help"), "help-browser-symbolic"))
+        self.list_box.add(SidebarRow(page, _("Help"), "help-browser-symbolic"))
 
         page = builder.get_object("page_contribute")
         self.stack.add_named(page, "page_contribute")
-        list_box.add(SidebarRow(page, _("Contribute"), "starred-symbolic"))
+        self.list_box.add(SidebarRow(page, _("Contribute"), "starred-symbolic"))
 
-        list_box.connect("row-activated", self.sidebar_row_selected_cb)
+        self.list_box.connect("row-activated", self.sidebar_row_selected_cb)
 
         # Construct the bottom toolbar
         box = builder.get_object("toolbar_bottom")
@@ -161,18 +162,6 @@ class MintWelcome():
         self.all_colors = ["green", "aqua", "blue", "brown", "grey", "orange", "pink", "purple", "red", "sand", "teal"]
         self.init_color_info()  # Sets self.dark_mode and self.color based on current system configuration
 
-        # Use HIDPI pictures if appropriate
-        if scale == 1:
-            surface = self.surface_for_path("/usr/share/linuxmint/mintwelcome/legacy.png", scale)
-            builder.get_object("img_legacy").set_from_surface(surface)
-            surface = self.surface_for_path("/usr/share/linuxmint/mintwelcome/modern.png", scale)
-            builder.get_object("img_modern").set_from_surface(surface)
-        else:
-            surface = self.surface_for_path("/usr/share/linuxmint/mintwelcome/legacy-hidpi.png", scale)
-            builder.get_object("img_legacy").set_from_surface(surface)
-            surface = self.surface_for_path("/usr/share/linuxmint/mintwelcome/modern-hidpi.png", scale)
-            builder.get_object("img_modern").set_from_surface(surface)
-
         path = "/usr/share/linuxmint/mintwelcome/colors/"
         if scale == 2:
             path = "/usr/share/linuxmint/mintwelcome/colors/hidpi/"
@@ -186,6 +175,10 @@ class MintWelcome():
         window.set_default_size(800, 500)
         window.show_all()
 
+    def go(self, button):
+        self.list_box.select_row(self.first_steps_row)
+        self.stack.set_visible_child_name("page_first_steps")
+
     def surface_for_path(self, path, scale):
         pixbuf = GdkPixbuf.Pixbuf.new_from_file(path)
 
@@ -222,7 +215,7 @@ class MintWelcome():
                           'panel1:right:11:calendar@cinnamon.org']
 
         applets_new = ['panel1:left:0:menu@cinnamon.org',
-                       'panel1:left:1:show-desktop@cinnamon.org',
+                       'panel1:left:1:separator@cinnamon.org',
                        'panel1:left:2:grouped-window-list@cinnamon.org',
                        'panel1:right:0:systray@cinnamon.org',
                        'panel1:right:1:xapp-status@cinnamon.org',
@@ -234,7 +227,8 @@ class MintWelcome():
                        'panel1:right:7:network@cinnamon.org',
                        'panel1:right:8:sound@cinnamon.org',
                        'panel1:right:9:power@cinnamon.org',
-                       'panel1:right:10:calendar@cinnamon.org']
+                       'panel1:right:10:calendar@cinnamon.org',
+                       'panel1:right:11:cornerbar@cinnamon.org']
 
         settings = Gio.Settings("org.cinnamon")
         settings.set_strv("panels-enabled", ['1:0:bottom'])
